==> qtjambi-designer-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDesigner/QDesignerPromotionInterface_shell.h <==
#ifndef QDESIGNERPROMOTIONINTERFACE_IMPL_SHELL_H
#define QDESIGNERPROMOTIONINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractpromotioninterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QSet>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>
#include <QtDesigner/abstractwidgetdatabase.h>
#include <QtJambi/RegistryAPI>


class QDesignerPromotionInterface_shell : public QDesignerPromotionInterface, public QtJambiShellInterface
{
public:
    QDesignerPromotionInterface_shell();
    ~QDesignerPromotionInterface_shell() override;

    bool addPromotedClass(const QString& baseClass0, const QString& className1, const QString& includeFile2, QString* errorMessage3) override;
    bool changePromotedClassName(const QString& oldClassName0, const QString& newClassName1, QString* errorMessage2) override;
    QList<QDesignerPromotionInterface::PromotedClass> promotedClasses() const override;
    QList<QDesignerWidgetDataBaseItemInterface*> promotionBaseClasses() const override;
    QSet<QString> referencedPromotedClassNames() const override;
    bool removePromotedClass(const QString& className0, QString* errorMessage1) override;
    bool setPromotedClassIncludeFile(const QString& className0, const QString& includeFile1, QString* errorMessage2) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerPromotionInterface_access : public QDesignerPromotionInterface
{
    jboolean __qt_addPromotedClass_cref_QString_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring baseClass0, jstring className1, jstring includeFile2, jobjectArray errorMessage3);
    jboolean __qt_changePromotedClassName_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring oldClassName0, jstring newClassName1, jobjectArray errorMessage2);
    jobject __qt_promotedClasses(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_promotionBaseClasses(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_referencedPromotedClassNames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_removePromotedClass_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, jobjectArray errorMessage1);
    jboolean __qt_setPromotedClassIncludeFile_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, jstring includeFile1, jobjectArray errorMessage2);
};

#endif // QDESIGNERPROMOTIONINTERFACE_IMPL_SHELL_H

==> qtjambi-designer-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiDesigner/QDesignerPromotionInterface_shell.h <==
#ifndef QDESIGNERPROMOTIONINTERFACE_IMPL_SHELL_H
#define QDESIGNERPROMOTIONINTERFACE_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractpromotioninterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QSet>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>
#include <QtDesigner/abstractwidgetdatabase.h>
#include <QtJambi/RegistryAPI>


class QDesignerPromotionInterface_shell : public QDesignerPromotionInterface, public QtJambiShellInterface
{
public:
    QDesignerPromotionInterface_shell();
    ~QDesignerPromotionInterface_shell() override;

    bool addPromotedClass(const QString& baseClass0, const QString& className1, const QString& includeFile2, QString* errorMessage3) override;
    bool changePromotedClassName(const QString& oldClassName0, const QString& newClassName1, QString* errorMessage2) override;
    QList<QDesignerPromotionInterface::PromotedClass> promotedClasses() const override;
    QList<QDesignerWidgetDataBaseItemInterface*> promotionBaseClasses() const override;
    QSet<QString> referencedPromotedClassNames() const override;
    bool removePromotedClass(const QString& className0, QString* errorMessage1) override;
    bool setPromotedClassIncludeFile(const QString& className0, const QString& includeFile1, QString* errorMessage2) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerPromotionInterface_access : public QDesignerPromotionInterface
{
    jboolean __qt_addPromotedClass_cref_QString_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring baseClass0, jstring className1, jstring includeFile2, jobjectArray errorMessage3);
    jboolean __qt_changePromotedClassName_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring oldClassName0, jstring newClassName1, jobjectArray errorMessage2);
    jobject __qt_promotedClasses_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_promotionBaseClasses_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_referencedPromotedClassNames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_removePromotedClass_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, jobjectArray errorMessage1);
    jboolean __qt_setPromotedClassIncludeFile_cref_QString_cref_QString_QString_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, jstring includeFile1, jobjectArray errorMessage2);
};

#endif // QDESIGNERPROMOTIONINTERFACE_IMPL_SHELL_H
